# react-foundation-components

Foundation Sites components implemented in React and compatible with CSS Modules!

## Why?

I like [React](https://facebook.github.io/react). I like [CSS Modules](https://github.com/css-modules/css-modules). I like [Foundation Sites](http://foundation.zurb.com/sites.html). This is an experiment to see if it's possible to combine all these tools in a modular way!

## Installation

```
npm install --save react-foundation-components
```

You must then choose to import Foundation Sites CSS stylesheets in 1 of a possible 3 ways:

1. Manual CSS
  * This mode is the default setting of this library.
  * You must manually add link tag pointing to Foundation Sites CSS stylesheet in your html. Please note that some components will be broken unless you also include CSS tweaks from [this custom stylesheet](https://github.com/aruberto/react-foundation-components/blob/master/src/custom.scss).
2. Global CSS
  * This mode is meant to be used with the [webpack](https://webpack.github.io/) or [browserify](http://browserify.org/) bundlers.
  * This mode is enabled by assigning process.env.REACT_FOUNDATION_COMPONENTS_CSS to 'global' using [webpack DefinePlugin](https://webpack.github.io/docs/list-of-plugins.html#defineplugin) or [envify for browserify](https://github.com/hughsk/envify) (set it similar to how would set process.env.NODE_ENV to 'production' to remove all dev only features from React).
  * Each component requires the subset of Foundation Sites CSS styles it needs. Therefore the CSS output the bundler spits out only contains the parts of Foundation Sites you actually need!
  * The CSS and JS generated by bundler will also use Foundation Sites global class names.
  * For webpack, you will need to setup [sass-loader](https://github.com/jtangelder/sass-loader) and [css-loader](https://github.com/webpack/css-loader). Example:
  ```
  loaders: [
    ...
    {
      test: /\.scss$/,
      loader: 'style!css!postcss!sass'
    },
    ...
  ]
  ```
  * For browserify, you will need to setup [sassify](https://github.com/davidguttman/sassify) or similar transform (not sure if this works, haven't tested any browserify setups yet).
3. Local CSS with CSS Modules
  * This mode is meant to be used with the [webpack](https://webpack.github.io/).
  * This mode is enabled by assigning process.env.REACT_FOUNDATION_COMPONENTS_CSS to 'modules' using [webpack DefinePlugin](https://webpack.github.io/docs/list-of-plugins.html#defineplugin) (set it similar to how would set process.env.NODE_ENV to 'production' to remove all dev only features from React).
  * Each component requires the subset of Foundation Sites CSS styles it needs. Therefore the final CSS output the bundler spits out only contains the parts of Foundation Sites you actually need!
  * The CSS and JS generated by bundler will use local scoped CSS class names. This avoids polluting global CSS name space with Foundation's class names!
  * For webpack, you will need to setup [sass-loader](https://github.com/jtangelder/sass-loader) and [css-loader](https://github.com/webpack/css-loader) with modules enabled. Example:
  ```
  loaders: [
    ...
    {
      test: /\.scss$/,
      loader: 'style!css?modules!postcss!sass'
    },
    ...
  ]
  ```
  * This mode will probably not work with browserify until [css-modulesify supports sass pre-processor](https://github.com/css-modules/css-modulesify/issues/14).

Demo of the components is available [here](http://aruberto.github.io/react-foundation-components). Please see [demo source code](https://github.com/aruberto/react-foundation-components/tree/master/demo) for an example webpack setup and example use of each component. Proper documentation to come later ...

Recommend importing on a per component basis instead of importing the main entry point of package. Importing main entry point will cause final bundle to include all CSS and JS whereas importing on a per component basis will cause your final bundle to only include the CSS and JS you actually need (this may change when tree shaking is introduced in webpack 2)!

Favor

```
import Button from 'react-foundation-components/lib/button';
import {ShowForScreenSize, HideForScreenSize} from 'react-foundation-components/lib/visibility';
```

over

```
import {Button, ShowForScreenSize, HideForScreenSize} from 'react-foundation-components';
```

## Thanks

A lot of the components are inspired by [React Bootstrap](https://github.com/react-bootstrap/react-bootstrap) and this project even makes heavy use their utility libraries like [react-overlays](https://github.com/react-bootstrap/react-overlays), [dom-helpers](https://github.com/react-bootstrap/dom-helpers), [react-prop-types](https://github.com/react-bootstrap/react-prop-types) and [uncontrollable](https://github.com/jquense/uncontrollable). So big thanks to all these project's contributers for all their amazing work!
